@@ -37,6 +37,7 @@ COLOR['LABEL'] = (0, 0, 0, 255)
 COLOR['GENE_POS'] = ImageColor.getrgb("#6961ff")
 # COLOR['GENE_NEG'] = ImageColor.getrgb("#e87489")
 COLOR['GENE_NEG'] = (232, 116, 137, 255)
+COLOR['GRID_COLOR'] = ImageColor.getrgb("#EEEEEE")
 
 
 # A: "rgb(  0, 200,   0)",
@@ -46,4 +47,6 @@ COLOR['GENE_NEG'] = (232, 116, 137, 255)
 
 IMAGE_MARGIN_BOTTOM = 20
 
-GENE_ANNOT_FILE  = "data/Homo_sapiens.GRCh38.99.bed.gz"
\ No newline at end of file
+GENE_ANNOT_FILE  = "Homo_sapiens.#REFSEQVERSION#.bed.gz"
+
+REFER_SEQ_VERSION = {'GRCh37': 'GRCh37', 'hg19':'GRCh37', 'GRCh38':'GRCh38', 'hg38':'GRCh38'}
